'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _babelPluginSyntaxJsx = require('babel-plugin-syntax-jsx');

var _babelPluginSyntaxJsx2 = _interopRequireDefault(_babelPluginSyntaxJsx);

var _babelTypes = require('babel-types');

var _babelTypes2 = _interopRequireDefault(_babelTypes);

var _createObjectExpression = require('./createObjectExpression');

var _createObjectExpression2 = _interopRequireDefault(_createObjectExpression);

var _requireCssModule = require('./requireCssModule');

var _requireCssModule2 = _interopRequireDefault(_requireCssModule);

var _resolveStringLiteral = require('./resolveStringLiteral');

var _resolveStringLiteral2 = _interopRequireDefault(_resolveStringLiteral);

var _replaceJsxExpressionContainer = require('./replaceJsxExpressionContainer');

var _replaceJsxExpressionContainer2 = _interopRequireDefault(_replaceJsxExpressionContainer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = (_ref) => {
  let t = _ref.types;

  let styleModuleImportMap;
  let importedHelperIndentifier;
  let styleModuleImportMapIdentifier;

  const setupFileForRuntimeResolution = path => {
    const programPath = path.findParent(parentPath => {
      return parentPath.isProgram();
    });

    importedHelperIndentifier = programPath.scope.generateUidIdentifier('getClassName');
    styleModuleImportMapIdentifier = programPath.scope.generateUidIdentifier('styleModuleImportMap');

    programPath.unshiftContainer('body', t.importDeclaration([t.importDefaultSpecifier(importedHelperIndentifier)], t.stringLiteral('babel-plugin-react-css-modules/dist/browser/getClassName')));

    const firstNonImportDeclarationNode = programPath.get('body').find(node => {
      return !t.isImportDeclaration(node);
    });

    firstNonImportDeclarationNode.insertBefore(t.variableDeclaration('const', [t.variableDeclarator(styleModuleImportMapIdentifier, (0, _createObjectExpression2.default)(t, styleModuleImportMap))]));
  };

  return {
    inherits: _babelPluginSyntaxJsx2.default,
    visitor: {
      ImportDeclaration(path, stats) {
        if (!path.node.source.value.endsWith('.css') && !path.node.source.value.endsWith('.scss')) {
          return;
        }

        const targetFileDirectoryPath = (0, _path.dirname)(stats.file.opts.filename);
        const targetResourcePath = (0, _path.resolve)(targetFileDirectoryPath, path.node.source.value);

        let styleImportName;

        if (path.node.specifiers.length === 0) {
          styleImportName = 'random-' + Math.random();
        } else if (path.node.specifiers.length === 1) {
          styleImportName = path.node.specifiers[0].local.name;
        } else {
          // eslint-disable-next-line no-console
          console.warn('Please report your use case. https://github.com/gajus/babel-plugin-react-css-modules/issues/new?title=Unexpected+use+case.');

          throw new Error('Unexpected use case.');
        }

        styleModuleImportMap[styleImportName] = (0, _requireCssModule2.default)(targetResourcePath, {
          generateScopedName: stats.opts.generateScopedName
        });
      },
      JSXElement(path) {
        const styleNameAttribute = path.node.openingElement.attributes.find(attribute => {
          return typeof attribute.name !== 'undefined' && attribute.name.name === 'styleName';
        });

        if (!styleNameAttribute) {
          return;
        }

        if (t.isStringLiteral(styleNameAttribute.value)) {
          (0, _resolveStringLiteral2.default)(path, styleModuleImportMap, styleNameAttribute);

          return;
        }

        if (t.isJSXExpressionContainer(styleNameAttribute.value)) {
          if (!importedHelperIndentifier) {
            setupFileForRuntimeResolution(path);
          }

          (0, _replaceJsxExpressionContainer2.default)(t, styleNameAttribute, importedHelperIndentifier, styleModuleImportMapIdentifier);
        }
      },
      Program() {
        styleModuleImportMap = {};
      }
    }
  };
};
//# sourceMappingURL=index.js.map